pub struct Builder { /* private fields */ }Expand description
Builder for the devtools-app plugin.
init is equivalent to Builder::new().build().
The custom_scheme_url closure receives a registered
custom-protocol name (e.g. isolation-…) and returns the URL it is served from, which is used
for the pre-auth devtools UI and the splashscreen. By default that URL comes from the webview runtime
({scheme}://localhost on wry, http://{scheme}.localhost on CEF and on Windows), so it only needs
to be set for runtimes that serve custom protocols somewhere else than they report.
Implementations
Sourceimpl Builder
impl Builder
pub fn new() -> Self
Sourcepub fn custom_scheme_url<F>(self, f: F) -> Self
pub fn custom_scheme_url<F>(self, f: F) -> Self
Overrides the URL custom protocols are served from instead of asking the webview runtime.
Sourcepub fn build<R: Runtime>(self) -> TauriPlugin<R>
pub fn build<R: Runtime>(self) -> TauriPlugin<R>
Builds the plugin (same as init when using default options).